@@ -264,8 +264,9 @@ ccp4_symop symop_to_rotandtrn(const char *symchs_begin, const char *symchs_end);
  */
 const char * symop_to_mat4(const char *symchs_begin, const char *symchs_end, float *rot);
 
-static 
+  /*
 int symop_to_mat4_err(const char *symop);
+  */
 
 ccp4_symop mat4_to_rotandtrn(const float rsm[4][4]);
 
